import os, sys, re, time, socket, select

from merlin_apps_utils import *
from merlin_qh import *
import compound_config as cconf

query_socket = False

def module_init(args):
	global query_socket

	if not query_socket:
		if os.access(nagios_cfg, os.R_OK):
			comp = cconf.parse_nagios_cfg(nagios_cfg)
			query_socket = comp.query_socket
		else:
			query_socket = '/opt/monitor/var/rw/nagios.qh'

	# load the merlin configuration, and thus all nodes
	mconf.parse()
	return 0

def cmd_core(args):
	"""
	Checks is a Slim Poller core container is considered healthy by checking
	that Naemon is alive and that all masters considers our configuration
	correct.
	Returns 0 		if all nodes are OK
	        1 		if naemon is not alive
		errors		number of misconfigured nodes
	"""

	sinfo = list(get_merlin_nodeinfo(query_socket))
	if not sinfo:
		print("Error: Naemon is not alive")
		return 1
	elif sinfo[0] == -1:
		print("Error: Naemon is not alive")
		return 1

	errors = 0
	for info in sinfo:
		node = mconf.configured_nodes.get(info['name'], False)
		is_running = info.get('state') == 'STATE_CONNECTED'
		if info["type"] == "master":
			last_alive = int(info.get('last_action', -1))
			# master is not connected BUT does seem alive recently
			# likely meaning we are misconfigured
			current_time = time.time()
			if not is_running and last_alive + 30 > current_time:
				print "Error: %s is alive but not connected!" % node
				errors = errors+1

	if errors == 0:
		print "OK"
	return errors

def cmd_merlin(args):
	"""
	Checks if the merlin IPC socket exists at var/run/naemon/merlin.sock
	returns 0 if file exists
		1 otherwise
	"""
	if os.path.exists('/var/run/naemon/merlin.sock'):
		print "OK"
		return 0
	else:
		print "Couldn't find IPC socket"
		return 1
